import just
import pandas as pd

from nostalgia.ndf import NDF
from nostalgia.times import parse_date_tz


class NsChipkaart(NDF):
    @classmethod
    def load(cls, nrows=None):
        files = just.glob("~/nostalgia_data/input/ns_chipkaart/reistransacties-*.xls")
        data = pd.concat([pd.read_excel(x, nrows=nrows) for x in files]).iloc[:-1]
        data["Datum"] = data["Datum"].apply(parse_date_tz)
        data["Vertrek"], data["Bestemming"] = data["Omschrijving"].str.split(":", 1).str[1].str.split(" - ", 1).str
        return cls(data)



from datetime import timedelta

import just
import pandas as pd

from nostalgia.ndf import NDF
from nostalgia.times import datetime_from_format

flatten = lambda l: [item for sublist in l for item in sublist]

class Spotify(NDF):
    @classmethod
    def load(cls, nrows=None):
        files = "~/nostalgia_data/input/spotify/StreamingHistory*.json"
        spotify = pd.DataFrame(
            [
                (
                    datetime_from_format(x["endTime"], "%Y-%m-%d %H:%M") - timedelta(milliseconds=x["msPlayed"]),
                    datetime_from_format(x["endTime"], "%Y-%m-%d %H:%M"),
                    x["trackName"],
                    x["artistName"],
                    x["msPlayed"] / 1000
                )
                for x in flatten(just.multi_read(files).values())
            ],
            columns=["time_start", "time_end", "title", "artist", "seconds"],
        )
        return cls(spotify)


if __name__ == "__main__":
    j = Spotify.load()
    print(j.create_sample_data())



from nostalgia.ndf import NDF


class Apple(NDF):
    vendor = "apple"
    ingest_settings = {
        "ingest_glob": "~/Downloads/apple/*.zip",
        "recent_only": False,
        "delete_existing": False,
    }

if __name__ == "__main__":
    Apple.ingest()


import just
import pandas as pd

from nostalgia.ndf import NDF
from nostalgia.times import datetime_from_format


class ICloud(NDF):
    @classmethod
    def load(cls, nrows=None):
        files = "~/nostalgia_data/input/apple/*/iCloudUsageData Set*.csv"

        icloud = pd.concat([pd.read_csv(f, skiprows=1, error_bad_lines=False) for f in just.glob(files)])
        icloud = icloud.iloc[:icloud.loc[icloud.Date == "Photos: Delete photo/video from iCloud Photo Library"].index.to_list()[0]]
        icloud["File Capture Date"] = icloud["File Capture Date"].apply(lambda x: datetime_from_format(x, "%Y-%m-%d"))
        return cls(icloud)

if __name__ == "__main__":
    j = ICloud.load()
    print(j.as_simple())



import pandas as pd
from nostalgia.ndf import NDF
from nostalgia.times import datetime_from_format
import re
import just
import time
import numpy as np
from nostalgia.times import datetime_from_timestamp
import os

def convert_date(date):
    return datetime_from_format(str(date),"%Y%m%d")

def find_date(x):
    date_regex = ".*(\d{2}[\.-]\d{2}[\.-]\d{2,4}[\/]\d{2}[\.-]\d{2}).*"
    value = str(x).replace('\\','\\\\')
    m = re.match(date_regex, value)
    if m:
        return datetime_from_format(m.group(1),"%d.%m.%y/%H.%M")

class AbnAmro(NDF):
    @classmethod
    def load(cls, nrows=None):
        files = just.glob('~/nostalgia_data/input/abnamro/*.xls')
        abn = pd.concat([pd.read_excel(x, nrows=nrows, converters={'transactiondate': convert_date}) for x in files])
        abn["preciseDate"] = abn["description"].apply(find_date)
        if abn.preciseDate.isnull().iloc[0]:
            abn.preciseDate.iloc[0] = abn.transactiondate.iloc[0]
        if abn.preciseDate.isnull().iloc[-1]:
            abn.preciseDate.iloc[-1] = abn.transactiondate.iloc[-1]

        abn.preciseDate = abn.preciseDate.map(lambda x: time.mktime(pd.datetime.timetuple(x)) if not pd.isna(x) else np.nan) \
            .interpolate('values') \
            .map(datetime_from_timestamp)


        return cls(abn)

if __name__ == "__main__":
    d = AbnAmro.load()
    print(d)


import just
import pandas as pd

from nostalgia.ndf import NDF

class StoresActivity(NDF):
    @classmethod
    def load(cls, nrows=None):
        files = "~/nostalgia_data/input/apple/*/Apple_Media_Services/Stores Activity/Account and Transaction History/Store*History.csv"
        dfs = [pd.read_csv(f, parse_dates=["Item Purchased Date"]) for f in just.glob(files)]
        applications = pd.merge(dfs[0], dfs[1], how="outer", on="Item Purchased Date")
        return cls(applications)


if __name__ == "__main__":
    j = StoresActivity.load()
    j.as_simple()



pdir(e)
e.as_string()
e.values()
e.get_payload()
e.get_payload()[0]
pdir(e.get_payload()[0])
e.get_payload()[0].get_payload()
e.get_payload()[1].get_payload()
import lxml.html
lxml.html.fromstring(e.get_payload()[1].get_payload())
html = lxml.html.fromstring(e.get_payload()[1].get_payload())
from requests_viewer import view_html
view_html(html)
view_tree(html)
from requests_viewer import view_tree
view_tree(html)
html.text_content()
print(html.text_content())
from auto_extract import parse_article
parse_article(html)
from auto_extract import Article
Article
?Article
help(Article)
a = Article(e.get_payload()[1].get_payload(), "")
a
a.content
a.body
pdir(a)
a.article_text
a.full_text
import justtext
import justext
pdir(justext)
justext.justext(e.get_payload()[1].get_payload())
justext.justext(e.get_payload()[1].get_payload(), [])
justext.justext(e.get_payload()[1].get_payload(), [])[0]
pdir(justext.justext(e.get_payload()[1].get_payload(), [])[0])
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), [])]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), []) if not x.is_boilerplate]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), []) if not x.is_boilerplate]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), []) if not x.is_boilerplate]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), []) if not x.is_boilerplate and x.is_heading]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), []) if not x.is_boilerplate or x.is_heading]
import just
import email
e=email.message_from_string(just.read("/home/pascal/.mail/outlook/Inbox/new/1582889346_0.7224.archbook,U=38807,FMD5=3882d32c66e7e768145ecd8f104b0c08:2,",unknown_type="txt"))
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), []) if not x.is_boilerplate or x.is_heading]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), [])]
[x.text for x in justext.justext(e.get_payload()[1].get_payload(), [])]
e.get_payload()[1].get_payload()
view_html(e.get_payload()[1].get_payload())



import pandas as pd
from pandas._config import get_option
from pandas.io.formats import console
from io import StringIO

ANONYMIZED = False

series_orig_repr = pd.Series.__repr__

# pd.Series.__repr__ = lambda *args: "a"


class AnonymizedSeries:
    def __init__(self, data, key):
        self.data = pd.Series(data)
        self._key = key

    def __len__(self):
        return len(self.data)

    def value_counts(self):
        return pd.Series(self.data).value_counts()._values

    def head(self):
        return AnonymizedSeries(pd.Series.head(self.data), self._key)

    def tail(self):
        return AnonymizedSeries(pd.Series.tail(self.data), self._key)

    def __repr__(self):
        return repr(pd.Series([self._key] * len(self)))

    def __getattribute__(self, key):
        if key == "iloc":
            raise ValueError("Cannot iloc anonymized object")
        return super().__getattribute__(key)

    @property
    def str(self):
        return pd.Series(self.data).str


def series_anon_repr(x):
    return "<AnonymizedSeries>"


class Anon:
    def __init__(self, key):
        self.key = key
        self.dc = {}
        self.star_num = len(key)

    def get_value(self, v):
        if v not in self.dc:
            self.dc[v] = len(self.dc)
        value = str(self.dc[v]).rjust(self.star_num, "*")
        return value


def normal(y):
    return str(y).replace("\n", "\\n")


class Anonymizer(pd.DataFrame):
    anonymized = []

    def __getitem__(self, key):
        if isinstance(key, str) and ANONYMIZED and key in self.anonymized:
            return AnonymizedSeries(pd.DataFrame.__getitem__(self, key), key)
        return pd.DataFrame.__getitem__(self, key)

    def __repr__(self) -> str:
        global ANONYMIZED
        if not ANONYMIZED:
            return super().__repr__()
        """
        Return a string representation for a particular DataFrame.
        """
        buf = StringIO("")
        if self._info_repr():
            self.info(buf=buf)
            return buf.getvalue()
        max_rows = get_option("display.max_rows")
        min_rows = get_option("display.min_rows")
        max_cols = get_option("display.max_columns")
        max_colwidth = get_option("display.max_colwidth")
        show_dimensions = get_option("display.show_dimensions")
        if get_option("display.expand_frame_repr"):
            width, _ = console.get_console_size()
        else:
            width = None
        formatters = [(Anon(x).get_value if x in self.anonymized else normal) for x in self.columns]
        self.to_string(
            buf=buf,
            max_rows=max_rows,
            min_rows=min_rows,
            max_cols=max_cols,
            line_width=width,
            max_colwidth=max_colwidth,
            show_dimensions=show_dimensions,
            formatters=formatters,
        )
        return buf.getvalue()

    @classmethod
    def is_anonymized(cls):
        return ANONYMIZED

    @classmethod
    def anonymize(cls):
        global ANONYMIZED
        ANONYMIZED = True

    @classmethod
    def reveal(cls):
        global ANONYMIZED
        ANONYMIZED = False
